@@ -31,7 +31,7 @@ MagicLabel::MagicLabel(TQString s, bool translate)
   transform();
 
   if (translate)
-    mValue = i18n(mValue);
+    mValue = i18n(mValue.utf8());
 }
 
 
